@@ -2,6 +2,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 
 import copy
+import collections
 import veriloggen.core.vtypes as vtypes
 from veriloggen.core.module import Module
 from . import util
@@ -93,7 +94,7 @@ def mkRAMDefinition(name, datawidth=32, addrwidth=10, numports=2,
 
 
 class RAMInterface(object):
-    _I = 'Reg'
+    _I = 'Wire'
     _O = 'Wire'
 
     def __init__(self, m, name=None, datawidth=32, addrwidth=10,
@@ -135,15 +136,15 @@ class RAMInterface(object):
             self.enable = util.make_port(m, itype, name_enable, initval=0)
 
     def connect(self, targ):
-        self.addr.connect(targ.addr)
-        targ.rdata.connect(self.rdata)
-        self.wdata.connect(targ.wdata)
-        self.wenable.connect(targ.wenable)
+        util.overwrite_assign(self.addr, targ.addr)
+        util.overwrite_assign(targ.rdata, self.rdata)
+        util.overwrite_assign(self.wdata, targ.wdata)
+        util.overwrite_assign(self.wenable, targ.wenable)
         if hasattr(self, 'enable'):
             if hasattr(targ, 'enable'):
-                self.enable.connect(targ.enable)
+                util.overwrite_assign(self.enable, targ.enable)
             else:
-                self.enable.connect(1)
+                util.overwrite_assign(self.enable, 1)
         else:
             if hasattr(targ, 'enable'):
                 raise ValueError('no enable port')
@@ -177,8 +178,11 @@ class _RAM_RTL(object):
         ram_def = mkRAMDefinition(name, datawidth, addrwidth, numports,
                                   initvals, sync, with_enable)
 
+        ports = collections.OrderedDict()
+        ports['CLK'] = self.clk
+        ports.update(m.connect_ports(ram_def))
         self.m.Instance(ram_def, name,
-                        params=(), ports=m.connect_ports(ram_def))
+                        params=(), ports=ports)
 
     def connect(self, port, addr, wdata, wenable, enable=None):
         self.m.Assign(self.interfaces[port].addr(addr))
